==> kdeedu-4.4.0.tar.bz2: kdeedu-4.4.0/kalgebra/analitzagui/tests/operatorsmodeltest.cpp <==
/*************************************************************************************
 *  Copyright (C) 2007 by Aleix Pol <aleixpol@kde.org>                               *
 *                                                                                   *
 *  This program is free software; you can redistribute it and/or                    *
 *  modify it under the terms of the GNU General Public License                      *
 *  as published by the Free Software Foundation; either version 2                   *
 *  of the License, or (at your option) any later version.                           *
 *                                                                                   *
 *  This program is distributed in the hope that it will be useful,                  *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
 *  GNU General Public License for more details.                                     *
 *                                                                                   *
 *  You should have received a copy of the GNU General Public License                *
 *  along with this program; if not, write to the Free Software                      *
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
 *************************************************************************************/

#include "operatorsmodeltest.h"
#include <analitza/expression.h>
#include <analitza/analitza.h>
#include <analitza/variables.h>
#include <qtest_kde.h>
#include <cmath>

using namespace std;
using Analitza::Expression;

QTEST_KDEMAIN_CORE( OperatorsModelTest )

OperatorsModelTest::OperatorsModelTest(QObject *parent)
	: QObject(parent)
{}

OperatorsModelTest::~OperatorsModelTest() {}
void OperatorsModelTest::initTestCase() {}
void OperatorsModelTest::cleanupTestCase() {}

void OperatorsModelTest::testExamples_data()
{
	QTest::addColumn<int>("i");
	for(int i=0; i<m.rowCount(); i++) {
		QModelIndex idx(m.index(i, 0));
		QTest::newRow(qPrintable(idx.data().toString())) << i;
	}
}

void OperatorsModelTest::testExamples()
{
	QFETCH(int, i);
	QModelIndex idx(m.index(i, 0));
	
	QModelIndex nameIdx, descriptionIdx, sampleIdx, exampleIdx;
	nameIdx = idx.sibling(idx.row(), 0);
	descriptionIdx = idx.sibling(idx.row(), 1);
	sampleIdx = idx.sibling(idx.row(), 2);
	exampleIdx = idx.sibling(idx.row(), 3);
	
	QString name=m.data(nameIdx).toString();
	QString description=m.data(descriptionIdx).toString();
	QString sample=m.data(sampleIdx).toString();
	QString example=m.data(exampleIdx).toString();
	
// 		qDebug() << "testing: " << name << example;
	
	QVERIFY(!name.isEmpty());
	QVERIFY(!description.isEmpty());
	QVERIFY(!sample.isEmpty());
	QVERIFY(!example.isEmpty());
	Expression ex(example, false);
	QCOMPARE(ex.toString(), example);
	
	Analitza::Analitza a;
	a.setExpression(ex);
	if(!a.isCorrect()) qDebug() << example << "1. error" << a.errors();// QVERIFY(a.isCorrect());
	
	a.simplify();
	if(!a.isCorrect()) qDebug() << example << "2. error" << a.errors();// QVERIFY(a.isCorrect());
	a.variables()->modify("x", 0.1);
	Expression e = a.calculate();
	if(!a.isCorrect()) qDebug() << example << "3. error" << a.errors();// QVERIFY(a.isCorrect());
	if(!e.isCorrect()) qDebug() << example << "4. error" << e.error(); // QVERIFY(e.isCorrect());
	QVERIFY(!a.expression().toMathMLPresentation().isEmpty());
	
	e = a.evaluate();
	if(!a.isCorrect()) qDebug() << example << "5. error" << a.errors();// QVERIFY(a.isCorrect());
	if(!e.isCorrect()) qDebug() << example << "6. error" << e.error(); // QVERIFY(e.isCorrect());
	QVERIFY(!a.expression().toMathMLPresentation().isEmpty());
}

#include "operatorsmodeltest.moc"

==> kdeedu-4.5.5.tar.bz2: kdeedu-4.5.5/kalgebra/analitzagui/tests/operatorsmodeltest.cpp <==
/*************************************************************************************
 *  Copyright (C) 2007 by Aleix Pol <aleixpol@kde.org>                               *
 *                                                                                   *
 *  This program is free software; you can redistribute it and/or                    *
 *  modify it under the terms of the GNU General Public License                      *
 *  as published by the Free Software Foundation; either version 2                   *
 *  of the License, or (at your option) any later version.                           *
 *                                                                                   *
 *  This program is distributed in the hope that it will be useful,                  *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
 *  GNU General Public License for more details.                                     *
 *                                                                                   *
 *  You should have received a copy of the GNU General Public License                *
 *  along with this program; if not, write to the Free Software                      *
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
 *************************************************************************************/

#include "operatorsmodeltest.h"
#include <analitza/expression.h>
#include <analitza/analyzer.h>
#include <analitza/variables.h>
#include <qtest_kde.h>
#include <cmath>

using namespace std;
using Analitza::Expression;

QTEST_KDEMAIN_CORE( OperatorsModelTest )

OperatorsModelTest::OperatorsModelTest(QObject *parent)
	: QObject(parent)
{}

OperatorsModelTest::~OperatorsModelTest() {}
void OperatorsModelTest::initTestCase() {}
void OperatorsModelTest::cleanupTestCase() {}

void OperatorsModelTest::testExamples_data()
{
	QTest::addColumn<int>("i");
	for(int i=0; i<m.rowCount(); i++) {
		QModelIndex idx(m.index(i, 0));
		QTest::newRow(qPrintable(idx.data().toString())) << i;
	}
}

void OperatorsModelTest::testExamples()
{
	QFETCH(int, i);
	QModelIndex idx(m.index(i, 0));
	
	QModelIndex nameIdx, descriptionIdx, sampleIdx, exampleIdx;
	nameIdx = idx.sibling(idx.row(), 0);
	descriptionIdx = idx.sibling(idx.row(), 1);
	sampleIdx = idx.sibling(idx.row(), 2);
	exampleIdx = idx.sibling(idx.row(), 3);
	
	QString name=m.data(nameIdx).toString();
	QString description=m.data(descriptionIdx).toString();
	QString sample=m.data(sampleIdx).toString();
	QString example=m.data(exampleIdx).toString();
	
// 		qDebug() << "testing: " << name << example;
	
	QVERIFY(!name.isEmpty());
	QVERIFY(!description.isEmpty());
	QVERIFY(!sample.isEmpty());
	QVERIFY(!example.isEmpty());
	Expression ex(example, false);
	QCOMPARE(ex.toString(), example);
	
	Analitza::Analyzer a;
	a.setExpression(ex);
	if(!a.isCorrect()) qDebug() << example << "1. error" << a.errors();// QVERIFY(a.isCorrect());
	
	a.simplify();
	if(!a.isCorrect()) qDebug() << example << "2. error" << a.errors();// QVERIFY(a.isCorrect());
	a.variables()->modify("x", 0.1);
	a.setExpression(ex);
	Expression e = a.calculate();
	if(!a.isCorrect()) qDebug() << example << "3. error" << a.errors();// QVERIFY(a.isCorrect());
	if(!e.isCorrect()) qDebug() << example << "4. error" << e.error(); // QVERIFY(e.isCorrect());
	QVERIFY(!a.expression().toMathMLPresentation().isEmpty());
	
	e = a.evaluate();
	if(!a.isCorrect()) qDebug() << example << "5. error" << a.errors();// QVERIFY(a.isCorrect());
	if(!e.isCorrect()) qDebug() << example << "6. error" << e.error(); // QVERIFY(e.isCorrect());
	QVERIFY(!a.expression().toMathMLPresentation().isEmpty());
}

#include "operatorsmodeltest.moc"
